@@ -88,8 +88,7 @@ my $has_ev_adns;
 sub has_ev_adns {
    ($has_ev_adns ||= do {
       my $model = AnyEvent::detect;
-      (($model eq "AnyEvent::Impl::CoroEV" or $model eq "AnyEvent::Impl::EV")
-       && eval { local $SIG{__DIE__}; require EV::ADNS })
+      ($model eq "AnyEvent::Impl::EV" && eval { local $SIG{__DIE__}; require EV::ADNS })
          ? 2 : 1 # so that || always detects as true
    }) - 1  # 2 => true, 1 => false
 }
@@ -106,6 +105,8 @@ sub inet_aton {
 
    if (&dotted_quad) {
       $cb->(Socket::inet_aton $name);
+   } elsif ($name eq "localhost") { # rfc2606 et al.
+      $cb->(v127.0.0.1);
    } elsif (&has_ev_adns) {
       EV::ADNS::submit ($name, &EV::ADNS::r_addr, 0, sub {
          my (undef, undef, @a) = @_;
@@ -116,6 +117,27 @@ sub inet_aton {
    }
 }
 
+=item AnyEvent::Util::fh_nonblocking $fh, $nonblocking
+
+Sets the blocking state of the given filehandle (true == nonblocking,
+false == blocking). Uses fcntl on anything sensible and ioctl FIONBIO on
+broken (i.e. windows) platforms.
+
+=cut
+
+sub fh_nonblocking($$) {
+   my ($fh, $nb) = @_;
+
+   require Fcntl;
+
+   if ($^O eq "MSWin32") {
+      $nb = (! ! $nb) + 0;
+      ioctl $fh, 0x8004667e, \$nb; # FIONBIO
+   } else {
+      fcntl $fh, &Fcntl::F_SETFL, $nb ? &Fcntl::O_NONBLOCK : 0;
+   }
+}
+
 1;
 
 =back
